@@ -1,4 +1,4 @@
-# $Progeny: main.py,v 1.46 2002/03/05 20:16:49 epg Exp $
+# $Progeny: main.py 4155 2004-03-18 18:44:44Z licquia $
 
 import configlet
 import gettext
@@ -19,18 +19,6 @@ def _(s):
 def _optionmenu_get_selected_item(self):
     return self.get_menu().get_active()
 
-# This will be provided by GTK+ 2.0
-def _optionmenu_get_history(self):
-    menu = self.get_menu()
-    children = menu.children()
-    item = menu.get_active()
-
-    for i in range(len(children)):
-        if children[i] == item:
-            break
-
-    return i
-
 def _get_devices():
     result = []
     netdev = open("/proc/net/dev")
@@ -101,12 +89,14 @@ class Etherconf(configlet.Configlet):
         self.manual_radiobutton = self.wtree.get_widget("manual_radiobutton")
         self.configuration_frame = self.wtree.get_widget("configuration_frame")
         self.removable_checkbutton = self.wtree.get_widget("removable_checkbutton")
+        self.detail_book = self.wtree.get_widget("detail_book")
         self.dhcp_frame = self.wtree.get_widget("dhcp_frame")
         self.dhcphost_entry = self.wtree.get_widget("dhcphost_entry")
         self.manual_frame = self.wtree.get_widget("manual_frame")
         self.ip_entry = self.wtree.get_widget("ip_entry")
         self.gateway_entry = self.wtree.get_widget("gateway_entry")
         self.netmask_entry = self.wtree.get_widget("netmask_entry")
+        self.nameservers_label = self.wtree.get_widget("nameservers_label")
         self.nameservers_entry = self.wtree.get_widget("nameservers_entry")
         self.mailhub_label = self.wtree.get_widget("mailhub_label")
         self.mailhub_entry = self.wtree.get_widget("mailhub_entry")
@@ -211,7 +201,18 @@ class Etherconf(configlet.Configlet):
                         info.gateway = value
 
         self.setup_menu(self.devices)
-        self.change_device(self.devices[0])
+        if self.devices:
+            self.change_device(self.devices[0])
+        else:
+            self.unconfigured_radiobutton.set_active(TRUE)
+            self.unconfigured_radiobutton.set_sensitive(FALSE)
+            self.dhcp_radiobutton.set_sensitive(FALSE)
+            self.manual_radiobutton.set_sensitive(FALSE)
+            self.configuration_frame.set_sensitive(FALSE)
+            self.nameservers_label.set_sensitive(FALSE)
+            self.nameservers_entry.set_sensitive(FALSE)
+            self.mailhub_label.set_sensitive(FALSE)
+            self.mailhub_entry.set_sensitive(FALSE)
 
     def validate(self):
         if len(self.hostname_entry.get_chars(0, -1)) == 0 \
@@ -309,7 +310,8 @@ Are you sure you want to proceed without any name servers?""",
         if not self.nameservers:
             self.nameservers = "none"
 
-        self.save_device(self.current)
+        if self.devices:
+            self.save_device(self.current)
 
     def report_debconf(self):
         results = []
@@ -368,30 +370,25 @@ Are you sure you want to proceed without any name servers?""",
         unconfigured = togglebutton.get_active()
         self.configuration_frame.set_sensitive(not unconfigured)
         if unconfigured:
-            self.dhcp_frame.hide()
-            self.manual_frame.hide()
+            self.detail_book.set_current_page(0)
 
     def on_dhcp_radiobutton_toggled(self, togglebutton):
         self.debug("on_dhcp_radiobutton_toggled")
         dhcp = togglebutton.get_active()
         self.dhcp_frame.set_sensitive(dhcp)
         if dhcp:
-            self.dhcp_frame.show()
-        else:
-            self.dhcp_frame.hide()
+            self.detail_book.set_current_page(1)
     
     def on_manual_radiobutton_toggled(self, togglebutton):
         self.debug("on_manual_radiobutton_toggled")
         manual = togglebutton.get_active()
         self.manual_frame.set_sensitive(manual)
         if manual:
-            self.manual_frame.show()
-        else:
-            self.manual_frame.hide()
+            self.detail_book.set_current_page(2)
 
     def on_device_menuitem_activate(self, menuitem):
         self.save_device(self.current)
-        device = self.devices[_optionmenu_get_history(self.device_optionmenu)]
+        device = self.devices[self.device_optionmenu.get_history()]
         self.change_device(device)
 
     # Internal methods
@@ -406,9 +403,9 @@ Are you sure you want to proceed without any name servers?""",
         return info
 
     def setup_menu(self, devices):
-        menu = gtk.GtkMenu()
+        menu = gtk.Menu()
         for i in devices:
-            item = gtk.GtkMenuItem(i)
+            item = gtk.MenuItem(i)
             item.connect("activate", self.on_device_menuitem_activate)
             menu.append(item)
         menu.show_all()
@@ -467,9 +464,10 @@ Are you sure you want to proceed without any name servers?""",
         #self.debug(info)
 
 _attrs = { "name": "etherconf",
-           "display_title": _("Configure Network Interfaces"),
+           "display_title": _("Network"),
            "description": _("Select this option to configure the devices your system uses to access networks such as the Internet."),
-           "packages": ["etherconf"]
+           "packages": ["etherconf"],
+           "api_version": 2
 }
 
 if os.path.exists("/usr/sbin/postfix"):
